@@ -196,7 +196,7 @@ static void tangle_grid_paint_aligned(TangleActor* actor, gfloat width, gfloat h
 
 		if (grid->priv->grid_spacing_x > 0.0) {
 			for (u = 0; u < grid->priv->line_width_y; u++) {
-				for (x = 0.0; x < width; x += grid->priv->grid_spacing_x) {
+				for (x = 1.0; x < width; x += grid->priv->grid_spacing_x) { /* TODO: Why 1.0? */
 					cogl_path_move_to(x + u, 0.0);
 					cogl_path_line_to(x + u, height);
 				}
@@ -216,7 +216,7 @@ static void tangle_grid_paint_aligned(TangleActor* actor, gfloat width, gfloat h
 			for (u = 0; u < grid->priv->line_width_x; u++) {
 				for (y = 0.0; y < height; y += grid->priv->grid_spacing_y) {
 					cogl_path_move_to(0.0, y + u);
-					cogl_path_line_to(width, y + u);
+					cogl_path_line_to(width + 1, y + u); /* TODO: Why + 1? */
 				}
 				cogl_path_stroke();
 			}
