@@ -23,8 +23,6 @@ typedef struct _TangleWidgetPrivate TangleWidgetPrivate;
 typedef struct _TangleWidget TangleWidget;
 typedef struct _TangleWidgetClass TangleWidgetClass;
 
-#include "tangle-event.h"
-
 struct _TangleWidget {
 	TangleActor parent_instance;
 	TangleWidgetPrivate* priv;
@@ -48,7 +46,7 @@ GType tangle_widget_get_type(void) G_GNUC_CONST;
 
 ClutterActor* tangle_widget_new(void);
 ClutterActor* tangle_widget_new_with_layout(TangleLayout* layout);
-ClutterActor* tangle_widget_new_with_parent(TangleWidget* parent);
+ClutterActor* tangle_widget_new_scrollable(TangleLayout* layout);
 
 guint tangle_widget_get_n_children(TangleWidget* widget);
 ClutterActor* tangle_widget_get_nth_child(TangleWidget* widget, guint n);
@@ -91,6 +89,9 @@ void tangle_widget_get_real_preferred_size(TangleWidget* widget, gboolean intera
 void tangle_widget_get_real_preferred_width(TangleWidget* widget, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p);
 void tangle_widget_get_real_preferred_height(TangleWidget* widget, gfloat for_width, gboolean interacting, gfloat* min_height_p, gfloat* natural_height_p, gfloat* max_height_p);
 
+gboolean tangle_widget_get_descendant_interacting(TangleWidget* widget);
+gboolean tangle_widget_get_descendant_dragging(TangleWidget* widget);
+
 void tangle_widget_clamp_child_boundaries(TangleWidget* widget, TangleClamp* clamp);
 
 #endif
